---@type Tinkr
local Tinkr,
---@class Bastion
Bastion = ...

---@class Bastion.APLActor2.Table.Base
---@field parentAPL Bastion.APL
---@field index number

-- Create an APL actor for the APL class
---@class Bastion.APLActor2
---@field traits Bastion.APLTrait[]
---@field table Bastion.APLActor2.Table.Base
---@field executor fun(self: Bastion.APLActor2): boolean
local APLActor = {}
APLActor.__index = APLActor

---@param type string
function APLActor:New(type)
    ---@class Bastion.APLActor2
    local self = setmetatable({
        type = type,
        enabled = true,
        traits = {},
        table = {},
        executor = function() return false end
    }, APLActor)
    return self
end

---@param ... any
function APLActor:GetName(...)
    local paramStrings = type(...) ~= "nil" and table.concat({ ... }, "-") or ""
    return string.format("[%s]%s", self.type, paramStrings)
end

-- Add a trait to the APL actor
---@param ... Bastion.APLTrait
---@return Bastion.APLActor2
function APLActor:AddTraits(...)
    for _, trait in ipairs({ ... }) do
        table.insert(self.traits, trait)
    end

    return self
end

-- Get the actor
---@return Bastion.APLActor2.Table.Base
function APLActor:GetActorTable()
    return self.table
end

function APLActor:SetExecutor(executor)
    self.executor = executor
end
